@@ -19,8 +19,7 @@ import uno
 import traceback
 
 from com.sun.star.frame.FrameSearchFlag import ALL
-from com.sun.star.util import URL
-from com.sun.star.i18n.KParseTokens import ANY_LETTER_OR_NUMBER, ASC_UNDERSCORE
+
 
 class Desktop(object):
 
